@@ -2,6 +2,7 @@
 
 import logging
 import jsonschema
+import iso8601
 
 from datetime import datetime
 from .fields import MsgFields as F, MsgErrs as MERR
@@ -62,8 +63,8 @@ class TaskResult(dict):
                              % (self.tmoid, type(self.tmoid)))
 
         # start the timer
-        self.time_start = iso_now()
-        self.time_end = None
+        self._time_start = iso_now()
+        self._time_end = None
 
         dict.__init__(self)
 
@@ -189,17 +190,45 @@ class TaskResult(dict):
         except KeyError:
             return
 
+    @property
+    def time_start_iso(self):
+        """
+        Return start time for a task
+        """
+        try:
+            return self[F.META][F.META_START_TIME]
+        except KeyError:
+            return
+
+    @property
+    def time_start(self):
+        return iso8601.parse_date(self.time_start_iso)
+
+    @property
+    def time_end_iso(self):
+        """
+        Return start time for a task
+        """
+        try:
+            return self[F.META][F.META_END_TIME]
+        except KeyError:
+            return
+
+    @property
+    def time_end(self):
+        return iso8601.parse_date(self.time_end_iso)
+
     def finish(self, err=None, msg=None):
         """
         Add the result for the event, any error messages, and stop the timer
         """
-        self.time_end = iso_now()
+        self._time_end = iso_now()
 
         self.setdefault(F.META, {})
         self[F.META][F.META_ERR] = err
         self[F.META][F.META_MSG] = msg
-        self[F.META][F.META_START_TIME] = self.time_start
-        self[F.META][F.META_END_TIME] = self.time_end
+        self[F.META][F.META_START_TIME] = self._time_start
+        self[F.META][F.META_END_TIME] = self._time_end
         self[F.META][F.META_VERSION] = self.task_version
 
         try:
