@@ -1,11 +1,14 @@
 # -*- coding: utf-8 -*-
 
+import logging
 import unittest
 import json
+from freezegun import freeze_time
+from datetime import datetime, timedelta
+from pytz import utc
 
 from ..taskresult import TaskResult, TaskSeed, SEED_VERSION
 from ..fields import MsgFields as F, MsgErrs as MERR
-from ..exceptions import ValidationError
 from ..schemas import build_schema
 
 
@@ -121,20 +124,28 @@ class TestTaskResult(unittest.TestCase):
         self.assertIsNotNone(tr.err)
 
     def test_timer_success(self):
-        tr = TaskResult(self.task_name, "1.1.1", 100)
-        tr.add("a", "My whois data")
-        tr.finish()
+        base_time = datetime(2016, 01, 01, 0, 0, 0)
+
+        with freeze_time(base_time):
+            tr = TaskResult(self.task_name, "1.1.1", 100)
+            tr.add("a", "My whois data")
+        with freeze_time(base_time + timedelta(seconds=2)):
+            tr.finish()
+        logging.debug(tr)
         self.assertIsNotNone(tr.time_end)
         self.assertLess(tr.time_start, tr.time_end)
 
-    def test_timer_fail(self):
-        tr = TaskResult(self.task_name, "1.1.1", 100)
-        tr.add("a", "My whois data")
-        tr.finish(err="Everything broke")
+    def test_timer_on_error(self):
+        base_time = datetime(2016, 01, 01, 0, 0, 0)
+
+        with freeze_time(base_time):
+            tr = TaskResult(self.task_name, "1.1.1", 100)
+            tr.add("a", "My whois data")
+        with freeze_time(base_time + timedelta(seconds=2)):
+            tr.finish(err="Everything broke")
+
         self.assertIsNotNone(tr.time_end)
         self.assertLess(tr.time_start, tr.time_end)
-        self.assertEqual(tr[F.META][F.META_START_TIME], tr.time_start)
-        self.assertEqual(tr[F.META][F.META_END_TIME], tr.time_end)
 
     def test_success(self):
         tr = TaskResult(self.task_name, "1.1.1", 100)
@@ -173,9 +184,12 @@ class TestTaskResult(unittest.TestCase):
         self.assertEqual(tr.version, "3.4.5")
 
     def test_obj_json_import(self):
-        tr = TaskResult(self.task_name, "1.1.1", 100)
-        tr.add("a", "My whois data")
-        tr.finish(err="Everything broke")
+        base_time = datetime(2016, 01, 01, 0, 0, 0)
+
+        with freeze_time(base_time):
+            tr = TaskResult(self.task_name, "1.1.1", 100)
+            tr.add("a", "My whois data")
+            tr.finish(err="Everything broke")
 
         tr_json = json.dumps(tr)
 
@@ -185,6 +199,8 @@ class TestTaskResult(unittest.TestCase):
         self.assertFalse(tr2.success)
         self.assertEqual(tr2.err, "Everything broke")
         self.assertEqual(tr2.task_version, "1.1.1")
+        self.assertEqual(tr2.time_start, base_time.replace(tzinfo=utc))
+        self.assertEqual(tr2.time_end, base_time.replace(tzinfo=utc))
 
     def test_schema_fail(self):
         tr = TaskResult(self.task_name, "1.1.1", 100)
@@ -221,7 +237,6 @@ class TestTaskResult(unittest.TestCase):
         tr.add("y", "My whois data")
         tr.finish()
 
-
         self.assertFalse(tr.success)
         self.assertTrue(tr.err.startswith(MERR.RESULT_INVALID.format("")))
 
